# !/bin/bash

#create a new directory for team 6
(qiime2-2023.7) root@083cc5135763:~/data# mkdir team6_dysautonomia_data

# go to /data/team6_dysautonomia_data

# importing and demultiplex data using manifest (run overnight - detached screen named KL_demux)
qiime tools import \
  --type "SampleData[PairedEndSequencesWithQuality]" \
  --input-format PairedEndFastqManifestPhred33V2 \
  --input-path /mnt/datasets/project_2/dysautonomia/dysautonomia_manifest.tsv \
  --output-path /data/team6_dysautonomia_data/team6_dysautonomia_paired_demux_seqs.qza

# creating a visualization of the demultiplexed samples
qiime demux summarize \
  --i-data team6_dysautonomia_paired_demux_seqs.qza \
  --o-visualization team6_dysautonomia_paired_demux_seqs.qzv

# transferred demux_seqs.qzv onto local computer and visualized the reads on view.QIIME2.org

# denoising and clustering using dada2 (run overnight - detach screen named denoising)
# creating representative sequences and table
qiime dada2 denoise-paired \
    --i-demultiplexed-seqs team6_dysautonomia_paired_demux_seqs.qza \
    --p-trunc-len-f 251 \
    --p-trunc-len-r 251 \
    --p-trim-left-f 0 \
    --p-trim-left-r 0 \
    --o-representative-sequences team6_rep-seq.qza \
    --o-table team6_dysautonomia_table.qza \
    --o-denoising-stats denoising-stats.qza

# creating visualizations of the denoised and clustered samples
qiime feature-table summarize \
  --i-table team6_dysautonomia_table.qza \
  --o-visualization team6_dysautonomia_table.qzv \
  --m-sample-metadata-file /mnt/datasets/project_2/dysautonomia/dysautonomia_metadata.tsv
  
qiime feature-table tabulate-seqs \
  --i-data team6_rep-seq.qza \
  --o-visualization team6_rep-seq.qzv

# Taxonomic analysis - Align database
qiime feature-classifier classify-sklearn \
  --i-classifier /mnt/datasets/classifiers/silva-138-99-515-806-nb-classifier.qza \
  --i-reads team6_rep-seq.qza \
  --o-classification team6_dysautonomia_taxonomy.qza

qiime metadata tabulate \
  --m-input-file team6_dysautonomia_taxonomy.qza \
  --o-visualization team6_dysautonomia_taxonomy.qzv

# Taxonomy barplots
qiime taxa barplot \
  --i-table team6_dysautonomia_table.qza \
  --i-taxonomy team6_dysautonomia_taxonomy.qza \
  --m-metadata-file /mnt/datasets/project_2/dysautonomia/dysautonomia_metadata.tsv \
  --o-visualization team6_dysautonomia_taxa-bar-plots.qzv

# Removing mitochondria or chloroplast sequences
qiime taxa filter-table \
  --i-table team6_dysautonomia_table.qza \
  --i-taxonomy team6_dysautonomia_taxonomy.qza \
  --p-exclude mitochondria,chloroplast \
  --o-filtered-table team6_dysautonomia_table-no-mitochondria-no-chloroplast.qza

qiime feature-table summarize \
  --i-table team6_dysautonomia_table-no-mitochondria-no-chloroplast.qza \
  --o-visualization team6_dysautonomia_table-no-mitochondria-no-chloroplast.qzv \
  --m-sample-metadata-file /mnt/datasets/project_2/dysautonomia/dysautonomia_metadata.tsv

# Generate a tree for phylogenetic diversity analyses
qiime phylogeny align-to-tree-mafft-fasttree \
  --i-sequences team6_rep-seq.qza \
  --o-alignment team6_dysautonomia_aligned-rep-seq.qza \
  --o-masked-alignment team6_dysautonomia_masked-aligned-rep-seq.qza \
  --o-tree team6_dysautonomia_unrooted-tree.qza \
  --o-rooted-tree team6_dysautonomia_rooted-tree.qza

# Alpha-rarefaction: based on team6_dysautonomia_table-no-mitochondria-no-chloroplast.qza
qiime diversity alpha-rarefaction \
  --i-table  team6_dysautonomia_table-no-mitochondria-no-chloroplast.qza \
  --i-phylogeny team6_dysautonomia_rooted-tree.qza \
  --p-max-depth 60000 \
  --m-metadata-file /mnt/datasets/project_2/dysautonomia/dysautonomia_metadata.tsv \
  --o-visualization team6_dysautonomia_alpha-rarefaction-no-mitochondria-no-chloroplast.qzv

# Alpha-rarefaction: based on team6_dysautonomia_table.qza
qiime diversity alpha-rarefaction \
  --i-table  team6_dysautonomia_table.qza \
  --i-phylogeny team6_dysautonomia_rooted-tree.qza \
  --p-max-depth 60000 \
  --m-metadata-file /mnt/datasets/project_2/dysautonomia/dysautonomia_metadata.tsv \
  --o-visualization team6_dysautonomia_alpha-rarefaction.qzv
